/*
 *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
 *
 *  $Id: class.c,v 1.5 2004/09/12 07:59:11 shuu Exp shuu $
 *
 *  Can be freely distributed and used under the terms of the GNU GPL.
 */
#include	<stdio.h>
#include	<stdlib.h>

#include	"murasaki.h"
#include	"murasaki_pci.h"

/*
 * format: x
 */
int
get_id_pci_class(mu_op_t *opp)
{
	char *ptr;
	MU_pci_config_t *config;

	config = opp->config;

	ptr = getenv("PCI_CLASS");
	if (ptr == NULL)
		return INVALID;

	config->class = strtoul(ptr,NULL,16);
	config->class_mask = 0;	/* not used */
	LOG_OPP_DESC("class 0x%x",config->class);

	return GOOD;
}

